@@ -184,6 +184,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -211,13 +213,13 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibana(
         cognito_domain_name: typing.Optional[builtins.str] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
-        dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
-        es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
+        dynamo_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -237,6 +239,10 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibana(
         :access: public
         :summary: Constructs a new instance of the LambdaToDynamoDB class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DynamoDBStreamsToLambdaToElasticSearchAndKibana.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps(
             domain_name=domain_name,
             cognito_domain_name=cognito_domain_name,
@@ -326,13 +332,13 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps:
         cognito_domain_name: typing.Optional[builtins.str] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
-        dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
-        es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
+        dynamo_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps, typing.Dict[str, typing.Any]]] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        es_domain_props: typing.Optional[typing.Union[aws_cdk.aws_elasticsearch.CfnDomainProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param domain_name: Cognito & ES Domain Name. Default: - None
@@ -359,6 +365,19 @@ class DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
             sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(DynamoDBStreamsToLambdaToElasticSearchAndKibanaProps.__init__)
+            check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
+            check_type(argname="argument cognito_domain_name", value=cognito_domain_name, expected_type=type_hints["cognito_domain_name"])
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument deploy_sqs_dlq_queue", value=deploy_sqs_dlq_queue, expected_type=type_hints["deploy_sqs_dlq_queue"])
+            check_type(argname="argument dynamo_event_source_props", value=dynamo_event_source_props, expected_type=type_hints["dynamo_event_source_props"])
+            check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
+            check_type(argname="argument es_domain_props", value=es_domain_props, expected_type=type_hints["es_domain_props"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_table_interface", value=existing_table_interface, expected_type=type_hints["existing_table_interface"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument sqs_dlq_queue_props", value=sqs_dlq_queue_props, expected_type=type_hints["sqs_dlq_queue_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
         }
